# Generated by Plain 0.68.1 on 2025-09-26 18:29

from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "plainpageviews",
            "0003_pageview_campaign_pageview_medium_pageview_source_and_more",
        ),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="pageview",
            name="plainpageviews_pageview_unique_uuid",
        ),
        migrations.RemoveField(
            model_name="pageview",
            name="uuid",
        ),
    ]
