{% extends "admin/cards/base.html" %}

{% block content %}

<div class="w-full space-y-2 overflow-auto max-h-60 flex-grow">
    {% for pageview in pageviews %}
    <div class="flex space-x-2 text-sm">
        <a
            class="flex-shrink-0 text-stone-500 tabular-nums hover:underline"
            href="{{ pageview|get_admin_model_detail_url }}"
            title="{{ pageview.timestamp }}">
            {{ pageview.timestamp|timesince(format="short", depth=1) }}
        </a>
        <a
            class="overflow-hidden hover:underline text-ellipsis whitespace-nowrap"
            title="{{ pageview.title }} ({{ pageview.url }})"
            href="{{ pageview.url }}">
            {{ pageview.title }}
        </a>
    </div>
    {% endfor %}
</div>

{% endblock %}
