# Generated by Plain 0.62.1 on 2025-09-10 02:26

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("plainpageviews", "0001_initial"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="pageview",
            name="plainpagevi_session_5545cf_idx",
        ),
        migrations.RenameField(
            model_name="pageview",
            old_name="session_key",
            new_name="session_id",
        ),
        migrations.AddIndex(
            model_name="pageview",
            index=models.Index(
                fields=["session_id"], name="plainpagevi_session_5b738a_idx"
            ),
        ),
    ]
